Draws the legend key glyphs used in geom_moon.
draw_key_moon(data, params, size)draw_key_moon_left(data, params, size)
draw_key_full_moon(data, params, size)
A single row data frame containing the scaled aesthetics to display in this key
A list of additional parameters supplied to the geom.
Width and height of key in mm.
A grid grob.
draw_key_moon (the default in geom_moon) draws a gibbous moon
filled from the right. draw_key_moon_left draws a crescent moon from
the right. draw_key_full_moon draws a circle, which is very similar to
draw_key_point in ggplot2, but the size is calculated slightly
differently and the default aesthetics differ.